@@ -13,5 +13,5 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .math_utils import infinity_norm
-from .time_utils import format_time
+import math_utils as math
+import time_utils as time
